ATCommonAdResponse class

CommonADCall payload; mainly impression revenue (adShowRevenueCallbackKeyATCommonAdStatus.adShowRevenuePaid).

Inheritance

Constructors

ATCommonAdResponse(ATCommonAdStatus status, Map extraMap, String errStr, String placementID)
ATCommonAdResponse.withMap(Map map)
factory

Properties

extraMap Map
final
hashCode int
The hash code for this object.
no setterinherited
isDeeplinkSuccess bool?
finalinherited
placementID String
finalinherited
requestMessage String
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status ATCommonAdStatus
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited