ATInitResponse class
Constructors
- ATInitResponse(dynamic consentSet, dynamic userLocation, dynamic consentDismiss)
- ATInitResponse.withMap(Map map)
-
factory
Properties
- consentDismiss → dynamic
-
InitCallNamedismiss payload:MapwithinfoMsg/dismissType, or legacyString.final - consentDismissSummary → String?
-
no setter
- consentSet → dynamic
-
final
- hasConsentDismiss → bool
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- userLocation → dynamic
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
formatConsentDismiss(
dynamic consentDismiss) → String? - Human-readable summary for UI / logs (UMP consent dialog dismiss).